summary refs log tree commit diff
path: root/pkgs/development/compilers/gcc/4.5/default.nix
diff options
context:
space:
mode:
Diffstat (limited to 'pkgs/development/compilers/gcc/4.5/default.nix')
-rw-r--r--pkgs/development/compilers/gcc/4.5/default.nix4
1 files changed, 2 insertions, 2 deletions
diff --git a/pkgs/development/compilers/gcc/4.5/default.nix b/pkgs/development/compilers/gcc/4.5/default.nix
index 6b2718f5e69..c63867a1d2d 100644
--- a/pkgs/development/compilers/gcc/4.5/default.nix
+++ b/pkgs/development/compilers/gcc/4.5/default.nix
@@ -317,8 +317,8 @@ stdenv.mkDerivation ({
 
     # Platform-specific flags
     optional (targetPlatform == hostPlatform && targetPlatform.isi686) "--with-arch=i686" ++
-    # Trick that should be taken out once we have a mips64el-linux not loongson2f
-    optional (targetPlatform == hostPlatform && stdenv.system == "mips64el-linux") "--with-arch=loongson2f"
+    # Trick that should be taken out once we have a mipsel-linux not loongson2f
+    optional (targetPlatform == hostPlatform && stdenv.system == "mipsel-linux") "--with-arch=loongson2f"
   ;
 
   targetConfig = if targetPlatform != hostPlatform then targetPlatform.config else null;